"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const react_redux_1 = require("react-redux");
const uuid_1 = require("uuid");
const document_widgets_1 = require("./components/document-widgets");
const DocumentViewer_1 = require("./components/DocumentViewer");
const LayoutAppBar_1 = require("./components/LayoutAppBar");
const core_1 = require("@material-ui/core");
const icons_1 = require("@material-ui/icons");
const DownloadWidget_1 = require("./components/document-widgets/DownloadWidget");
const PrintWidget_1 = require("./components/document-widgets/PrintWidget");
const ShareWidget_1 = require("./components/document-widgets/ShareWidget");
/**
 * Adds a globally unique ID to the shape
 */
const addGuidToShape = (shape) => {
    shape.guid = uuid_1.v1();
    return shape;
};
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
const mapStateToProps = (state, ownProps) => {
    return {};
};
/**
 * mapDispatchToProps for the example app layout component
 */
const mapDispatchToProps = {};
/**
 * Settings object for the Document Viewer Example component
 */
exports.exampleSettings = {
    canEditDocument: (documentData) => __awaiter(this, void 0, void 0, function* () {
        const response = yield fetch(`${encodeURI(documentData.hostName)}/odata.svc/${encodeURI(documentData.idOrPath.toString())}/HasPermission?permissions=Save`, { method: 'GET', credentials: 'include' });
        if (response.ok) {
            return (yield response.text()) === 'true';
        }
        return false;
    }),
    saveChanges: (documentData, pages) => __awaiter(this, void 0, void 0, function* () {
        const reqBody = {
            Shapes: JSON.stringify([
                { redactions: documentData.shapes.redactions },
                { highlights: documentData.shapes.highlights },
                { annotations: documentData.shapes.annotations },
            ]),
            PageAttributes: JSON.stringify(pages.map((p) => p.Attributes && p.Attributes.degree && { pageNum: p.Index, options: p.Attributes } || undefined).filter((p) => p !== undefined)),
        };
        yield fetch(`${documentData.hostName}/odata.svc/${documentData.idOrPath}`, {
            method: 'PATCH',
            body: JSON.stringify(reqBody),
            credentials: 'include',
        });
    }),
    canHideWatermark: (documentData) => __awaiter(this, void 0, void 0, function* () {
        const response = yield fetch(`${documentData.hostName}/odata.svc/${documentData.idOrPath}/HasPermission?permissions=PreviewWithoutWatermark`, { credentials: 'include' });
        if (response.ok) {
            return (yield response.text()) === 'true';
        }
        return false;
    }),
    canHideRedaction: (documentData) => __awaiter(this, void 0, void 0, function* () {
        const response = yield fetch(`${documentData.hostName}/odata.svc/${documentData.idOrPath}/HasPermission?permissions=PreviewWithoutRedaction`, { credentials: 'include' });
        if (response.ok) {
            return (yield response.text()) === 'true';
        }
        return false;
    }),
    getExistingPreviewImages: (documentData, version) => __awaiter(this, void 0, void 0, function* () {
        const response = yield fetch(`${documentData.hostName}/odata.svc/${documentData.idOrPath}/GetExistingPreviewImages?version=${version}`, { method: 'POST', credentials: 'include' });
        const availablePreviews = (yield response.json()).map((a) => {
            if (a.PreviewAvailable) {
                a.PreviewImageUrl = `${documentData.hostName}${a.PreviewAvailable}`;
                a.ThumbnailImageUrl = `${documentData.hostName}${a.PreviewAvailable.replace('preview', 'thumbnail')}`;
            }
            return a;
        });
        const allPreviews = [];
        for (let i = 0; i < documentData.pageCount; i++) {
            allPreviews[i] = availablePreviews[i] || { Index: i + 1 };
            const pageAttributes = documentData.pageAttributes.find((p) => p.pageNum === allPreviews[i].Index);
            allPreviews[i].Attributes = pageAttributes && pageAttributes.options;
        }
        return allPreviews;
    }),
    isPreviewAvailable: (documentData, version, page, showWatermark) => __awaiter(this, void 0, void 0, function* () {
        const response = yield fetch(`${documentData.hostName}/odata.svc/${documentData.idOrPath}/PreviewAvailable?version=${version}`, {
            method: 'POST',
            body: JSON.stringify({ page }),
            credentials: 'include',
        });
        if (response.ok) {
            const responseBody = yield response.json();
            if (responseBody.PreviewAvailable) {
                responseBody.PreviewImageUrl = `${documentData.hostName}${responseBody.PreviewAvailable}`;
                responseBody.ThumbnailImageUrl = `${documentData.hostName}${responseBody.PreviewAvailable.replace('preview', 'thumbnail')}`;
                return responseBody;
            }
        }
        return;
    }),
    getDocumentData: (documentData) => __awaiter(this, void 0, void 0, function* () {
        const docData = yield fetch(`${documentData.hostName}/odata.svc/` + documentData.idOrPath, {
            credentials: 'include',
        });
        if (!docData.ok) {
            const e = new Error('Error fetching document');
            e.status = docData.status;
            throw e;
        }
        const body = yield docData.json();
        return {
            idOrPath: documentData.idOrPath,
            hostName: documentData.hostName,
            fileSizekB: body.d.Size,
            pageCount: body.d.PageCount,
            documentName: body.d.DisplayName,
            documentType: body.d.Type,
            shapes: body.d.Shapes && {
                redactions: JSON.parse(body.d.Shapes)[0].redactions.map((a) => addGuidToShape(a)) || [],
                annotations: JSON.parse(body.d.Shapes)[2].annotations.map((a) => addGuidToShape(a)) || [],
                highlights: JSON.parse(body.d.Shapes)[1].highlights.map((a) => addGuidToShape(a)) || [],
            } || {
                redactions: [],
                annotations: [],
                highlights: [],
            },
            pageAttributes: body.d.PageAttributes && JSON.parse(body.d.PageAttributes) || [],
        };
    }),
};
const localStorageKey = 'sn-docviewer-example';
/**
 * The default example theme
 */
exports.exampleTheme = core_1.createMuiTheme({
    palette: {
        primary: {
            main: '#ff9800',
        },
        secondary: {
            main: '#ff9800',
        },
        background: {
            default: '#f5f5f5',
            paper: '#ffffff',
        },
    },
    overrides: {
        MuiDrawer: {
            paper: {
                backgroundColor: 'transparent',
            },
            docked: {
                backgroundColor: '#eaeaeb',
            },
        },
        MuiToolbar: {
            root: {
                backgroundColor: '#2a2a2c',
                color: '#707070',
            },
        },
    },
});
class ExampleAppLayout extends React.Component {
    constructor() {
        super(...arguments);
        /** the component state */
        this.state = JSON.parse(localStorage.getItem(localStorageKey)) || {
            hostName: '',
            documentIdOrPath: ``,
            isViewerOpened: false,
            settings: exports.exampleSettings,
            isHelpOpened: false,
        };
    }
    /**
     * Overridden setState() method that also persists the state in the local storage
     * @param newState The new State instance
     */
    setState(newState) {
        super.setState(newState);
        if (newState.save) {
            localStorage.setItem(localStorageKey, JSON.stringify(newState));
        }
        else {
            localStorage.removeItem(localStorageKey);
        }
    }
    openViewer(ev) {
        ev.preventDefault();
        this.setState(Object.assign({}, this.state, { isViewerOpened: true }));
    }
    closeViewer() {
        this.setState(Object.assign({}, this.state, { isViewerOpened: false }));
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement(core_1.MuiThemeProvider, { theme: exports.exampleTheme },
            React.createElement("div", { style: { height: '100%' } },
                this.state.isViewerOpened ?
                    React.createElement(DocumentViewer_1.DocumentViewer, { hostName: this.state.hostName, documentIdOrPath: this.state.documentIdOrPath },
                        React.createElement(LayoutAppBar_1.LayoutAppBar, null,
                            React.createElement("div", { style: { flexShrink: 0 } },
                                React.createElement(document_widgets_1.ToggleThumbnailsWidget, null),
                                React.createElement(DownloadWidget_1.Download, { download: (doc) => {
                                        // tslint:disable-next-line:no-console
                                        console.log('Download triggered', doc);
                                    } }),
                                React.createElement(PrintWidget_1.Print, { print: (doc) => {
                                        // tslint:disable-next-line:no-console
                                        console.log('Print triggered', doc);
                                    } }),
                                React.createElement(ShareWidget_1.Share, { share: (doc) => {
                                        // tslint:disable-next-line:no-console
                                        console.log('Share triggered', doc);
                                    } }),
                                React.createElement(document_widgets_1.ZoomInOutWidget, null),
                                React.createElement(document_widgets_1.RotateActivePages, null)),
                            React.createElement(document_widgets_1.DocumentTitlePager, null),
                            React.createElement("div", { style: { flexShrink: 0 } },
                                React.createElement(document_widgets_1.SearchBar, null))))
                    :
                        React.createElement("div", { style: {
                                display: 'flex',
                                justifyContent: 'space-around',
                                alignContent: 'center',
                                alignItems: 'center',
                                height: '100%',
                            } },
                            React.createElement(core_1.Paper, { elevation: 4, style: {
                                    padding: '1.2rem',
                                    flexGrow: 1,
                                    maxWidth: '65%',
                                } },
                                React.createElement(core_1.Typography, { variant: "title" }, "Document Viewer Demo"),
                                React.createElement(core_1.Typography, null, "Select a sensenet site and document to open."),
                                React.createElement("form", { autoComplete: "off", autoCorrect: "off", onSubmit: (ev) => this.openViewer(ev), style: {
                                        margin: '.5em',
                                        display: 'flex',
                                        flexDirection: 'column',
                                    } },
                                    React.createElement(core_1.TextField, { value: this.state.hostName, onChange: (ev) => { this.setState(Object.assign({}, this.state, { hostName: ev.currentTarget.value })); }, required: true, placeholder: "The host URL, e.g. 'https://my-sensenet-site.org'", type: "url", label: "Host name", margin: "normal" }),
                                    React.createElement(core_1.TextField, { value: this.state.documentIdOrPath, onChange: (ev) => { this.setState(Object.assign({}, this.state, { documentIdOrPath: ev.currentTarget.value })); }, required: true, margin: "normal", placeholder: "The Id or full path of the document, e.g.: /Root/Sites/MySite/MyDocLib/('Example.docx')", label: "Document id / full path" }),
                                    React.createElement("div", { style: {
                                            display: 'flex',
                                            flexDirection: 'row-reverse',
                                            marginTop: '1em',
                                        } },
                                        React.createElement(core_1.Button, { type: "submit", variant: "raised", color: "primary" },
                                            " ",
                                            React.createElement(icons_1.Send, null),
                                            " \u00A0 Open "),
                                        "\u00A0",
                                        React.createElement(core_1.Button, { onClick: (ev) => this.setState(Object.assign({}, this.state, { isHelpOpened: true })), variant: "raised", color: "primary" },
                                            " ",
                                            React.createElement(icons_1.Help, null),
                                            " \u00A0 Help "),
                                        "\u00A0",
                                        React.createElement(core_1.FormControlLabel, { control: React.createElement(core_1.Checkbox, { checked: this.state.save, onChange: (ev) => this.setState(Object.assign({}, this.state, { save: !this.state.save })), value: "checkedA" }), label: "Remember" }))),
                                React.createElement(core_1.Dialog, { open: this.state.isHelpOpened || false },
                                    React.createElement(core_1.DialogTitle, null, "Help"),
                                    React.createElement(core_1.DialogContent, null,
                                        React.createElement(core_1.Typography, { component: "div" },
                                            "If you have trouble opening a file be sure that",
                                            React.createElement("ul", null,
                                                React.createElement("li", null,
                                                    "you are using sensenet ",
                                                    React.createElement("a", { href: "https://community.sensenet.com/docs/install-sn-from-nuget/", target: "_blank" }, "7.0+")),
                                                React.createElement("li", null,
                                                    React.createElement("a", { href: "https://community.sensenet.com/docs/cors/", target: "_blank" }, "CORS"),
                                                    " is allowed for the current host"),
                                                React.createElement("li", null, "You are logged in"),
                                                React.createElement("li", null, "You have Open rights to the document"),
                                                React.createElement("li", null, "The preview images has been generated or Task Management is configured")))),
                                    React.createElement(core_1.DialogActions, null,
                                        React.createElement(core_1.Button, { onClick: (ev) => this.setState(Object.assign({}, this.state, { isHelpOpened: false })), variant: "raised", color: "primary" }, " Close "))))),
                this.state.isViewerOpened ?
                    React.createElement(core_1.Button, { style: {
                            position: 'fixed',
                            right: '2em',
                            bottom: '1em',
                            zIndex: 1,
                        }, variant: "fab", color: "secondary", "aria-label": "select another document", onClick: (ev) => this.closeViewer() },
                        React.createElement(icons_1.FolderOpen, null))
                    : null)));
    }
}
const connectedComponent = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(ExampleAppLayout);
exports.ExampleAppLayout = connectedComponent;
//# sourceMappingURL=ExampleAppLayout.js.map