"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@material-ui/core");
const icons_1 = require("@material-ui/icons");
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        canHideWatermark: state.sensenetDocumentViewer.documentState.canHideWatermark,
        showWatermark: state.sensenetDocumentViewer.viewer.showWatermark,
        toggleWatermark: state.sensenetDocumentViewer.localization.toggleWatermark,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    setWatermark: store_1.setWatermark,
};
/**
 * Document widget component that toggles the displaying of the watermark
 */
class ToggleWatermarkComponent extends React.Component {
    toggleWatermark() {
        this.props.setWatermark(!this.props.showWatermark);
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement("div", { style: { display: 'inline-block' } },
            React.createElement(core_1.IconButton, { title: this.props.toggleWatermark, style: { opacity: this.props.showWatermark ? 1 : 0.5 } },
                React.createElement(icons_1.BrandingWatermark, { onClick: () => this.toggleWatermark() }))));
    }
}
exports.ToggleWatermarkComponent = ToggleWatermarkComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(ToggleWatermarkComponent);
exports.ToggleWatermarkWidget = connectedComponent;
//# sourceMappingURL=ToggleWatermark.js.map